@@ -1,5 +1,5 @@
 /* libinfinity - a GObject-based infinote implementation
- * Copyright (C) 2007-2014 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2007-2015 Armin Burgmeier <armin@arbur.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -313,6 +313,9 @@ inf_xmpp_connection_site_get_type(void) G_GNUC_CONST;
 GType
 inf_xmpp_connection_get_type(void) G_GNUC_CONST;
 
+GQuark
+inf_xmpp_connection_error_quark(void);
+
 InfXmppConnection*
 inf_xmpp_connection_new(InfTcpConnection* tcp,
                         InfXmppConnectionSite site,
@@ -332,11 +335,27 @@ inf_xmpp_connection_get_own_certificate(InfXmppConnection* xmpp);
 InfCertificateChain*
 inf_xmpp_connection_get_peer_certificate(InfXmppConnection* xmpp);
 
+gnutls_kx_algorithm_t
+inf_xmpp_connection_get_kx_algorithm(InfXmppConnection* xmpp);
+
+gnutls_cipher_algorithm_t
+inf_xmpp_connection_get_cipher_algorithm(InfXmppConnection* xmpp);
+
+gnutls_mac_algorithm_t
+inf_xmpp_connection_get_mac_algorithm(InfXmppConnection* xmpp);
+
+gnutls_protocol_t
+inf_xmpp_connection_get_tls_protocol(InfXmppConnection* xmpp);
+
+guint
+inf_xmpp_connection_get_dh_prime_bits(InfXmppConnection* xmpp);
+
 void
 inf_xmpp_connection_set_certificate_callback(InfXmppConnection* xmpp,
                                              gnutls_certificate_request_t req,
                                              InfXmppConnectionCrtCallback cb,
-                                             gpointer user_data);
+                                             gpointer user_data,
+                                             GDestroyNotify notify);
 
 void
 inf_xmpp_connection_certificate_verify_continue(InfXmppConnection* xmpp);
